@@ -249,22 +249,24 @@ def stacked_bar(x, y,
 
 def hist(data,
     bins = None,
+    width = None,
+    norm = False,
     yside = None,
     xside = None,
     marker = None,
     color = None,
     fill = True,
-    width = None,
     orientation = None,
     label = None):
     figure.subplot.draw_hist(data,
     bins = bins,
+    width = width,
+    norm = norm,
     xside = xside,
     yside = yside,
     marker = marker,
     color = color,
     fill = fill,
-    width = width,
     orientation = orientation,
     label = label)
 
